@@ -44,17 +44,19 @@ class VmCommand(PluginCommand):
                         [--cloud=CLOUDS]
                         [--output=OUTPUT]
                         [--refresh]
+                        [--short]
                 vm boot [--n=COUNT]
-                        [--name=VMNAMES]
+                        [--name=NAMES]
                         [--label=LABEL]
                         [--cloud=CLOUD]
                         [--username=USERNAME]
                         [--image=IMAGE]
                         [--flavor=FLAVOR]
+                        [--size=SIZE]
                         [--network=NETWORK]
                         [--public]
-                        [--secgroup=SECGROUPs]
-                        [--group=GROUPs]
+                        [--secgroup=SECGROUP]
+                        [--group=GROUP]
                         [--key=KEY]
                         [--dryrun]
                         [-v]
@@ -353,7 +355,9 @@ class VmCommand(PluginCommand):
                 provider = Provider(name=cloud)
                 vms = provider.list()
 
-                provider.Print(vms, output=arguments.output, kind="vm")
+                provider.Print(vms,
+                               output=arguments.output,
+                               kind="vm")
 
                 return ""
 
@@ -615,18 +619,21 @@ class VmCommand(PluginCommand):
 
             """
                 vm boot 
-                        [--name=VMNAMES]
+                        [--n=COUNT]
+                        [--name=NAMES]
                         [--label=LABEL]
                         [--cloud=CLOUD]
                         [--username=USERNAME]
                         [--image=IMAGE]
                         [--flavor=FLAVOR]
+                        [--size=SIZE]
                         [--network=NETWORK]
                         [--public]
                         [--secgroup=SECGROUP]
-                        [--key=KEY]
                         [--group=GROUP]
+                        [--key=KEY]
                         [--dryrun]
+                        [-v]
             """
             # for name in names:
             #    node = p.create(name=name, size=flavor, image=image)
@@ -654,6 +661,7 @@ class VmCommand(PluginCommand):
                               "username",
                               "flavor",
                               "key",
+                              "size",
                               "network",
                               "secgroup"]:
                 parameters[attribute] = Parameter.find(attribute,
